
DS Cleaner
===========

DS Cleaner allows for easy cleanup of energy disagregation datasets and allows
for easy wave convertion.

This library is based in librosa and PySoundFile library.

Visit the Jupyter notebook for examples, available here: NOt available yet:

View the documentation in ReadTheDocs!

dscleaner.rtfd.io